@@ -15,7 +15,10 @@ from typing import Dict, Any, Optional, List, Tuple
 
 from .models import Message, TextContent, MessageRole, Conversation
 from .client import A2AClient, AgentNetwork, StreamingClient
-from .server import A2AServer, run_server
+# Replace Flask server import with FastAPI server import
+# from .server import A2AServer, run_server # Old Flask server
+from .server import A2AServer # A2AServer class is still needed
+from .server.fastapi_server import run_fastapi_server # New FastAPI server runner
 from .utils import (
     pretty_print_message,
     pretty_print_conversation,
@@ -88,24 +91,16 @@ def serve_command(args: argparse.Namespace) -> int:
         Exit code (0 for success, non-zero for failure)
     """
     try:
-        # Try to import Flask
-        try:
-            from flask import Flask
-        except ImportError:
-            raise A2AImportError(
-                "Flask is not installed. "
-                "Install it with 'pip install flask'"
-            )
-        
         # Create a simple A2A server
-        agent = A2AServer()
+        agent = A2AServer() # This class now handles FastAPI setup via its setup_routes
         
-        # Start the server
-        run_server(
+        print(f"Starting A2A FastAPI server on http://{args.host}:{args.port}")
+        # Start the server using the FastAPI runner
+        run_fastapi_server(
             agent=agent,
             host=args.host,
             port=args.port,
-            debug=args.debug
+            log_level="debug" if args.debug else "info"
         )
         
         return 0
@@ -155,12 +150,12 @@ def openai_command(args: argparse.Namespace) -> int:
         print(f"Starting OpenAI-powered A2A server with model {args.model}")
         print(f"System prompt: {args.system_prompt}")
         
-        # Start the server
-        run_server(
+        # Start the server using the FastAPI runner
+        run_fastapi_server(
             agent=agent,
             host=args.host,
             port=args.port,
-            debug=args.debug
+            log_level="debug" if args.debug else "info"
         )
         
         return 0
@@ -211,12 +206,12 @@ def anthropic_command(args: argparse.Namespace) -> int:
         print(f"Starting Anthropic-powered A2A server with model {args.model}")
         print(f"System prompt: {args.system_prompt}")
         
-        # Start the server
-        run_server(
+        # Start the server using the FastAPI runner
+        run_fastapi_server(
             agent=agent,
             host=args.host,
             port=args.port,
-            debug=args.debug
+            log_level="debug" if args.debug else "info"
         )
         
         return 0
@@ -376,12 +371,12 @@ def mcp_agent_command(args: argparse.Namespace) -> int:
                 elif isinstance(config, dict) and "url" in config:
                     print(f"  - {name}: {config['url']}")
         
-        # Start the server
-        run_server(
+        # Start the server using the FastAPI runner
+        run_fastapi_server(
             agent=agent,
             host=args.host,
             port=args.port,
-            debug=args.debug
+            log_level="debug" if args.debug else "info"
         )
         
         return 0
