@@ -17,14 +17,14 @@ Usage:
     enable_discovery(server, registry_url="http://localhost:8000")
 """
 
-from .registry import AgentRegistry, run_registry
+# from .registry import AgentRegistry, run_registry # These are Flask-based server components
 from .client import DiscoveryClient
-from .server import enable_discovery, RegistryAgent
+# from .server import enable_discovery, RegistryAgent # These are likely Flask-based server components too
 
 __all__ = [
-    'AgentRegistry',
-    'run_registry',
+    # 'AgentRegistry', # Flask-based
+    # 'run_registry',  # Flask-based
     'DiscoveryClient',
-    'enable_discovery',
-    'RegistryAgent'
+    # 'enable_discovery', # Likely Flask-based
+    # 'RegistryAgent'     # Likely Flask-based
 ]
